PromiseState in js_sys - Rust (original) (raw)
Struct PromiseState
pub struct PromiseState<T = JsValue> { /* private fields */ }Expand description
The PromiseState object represents the the status of the promise, as used in allSettled.
A string, either “fulfilled” or “rejected”, indicating the eventual state of the promise.
Only present if status is “fulfilled”. The value that the promise was fulfilled with.
Only present if status is “rejected”. The reason that the promise was rejected with.
The constructor property returns a reference to the Object constructor function that created the instance object.
👎Deprecated: Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).
The isPrototypeOf() method checks if an object exists in another object’s prototype chain.
The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.
The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.
The valueOf() method returns the primitive value of the specified object.
Returns the f64 value of this JS value if it’s an instance of a number.
If this JS value is not an instance of a number then this returnsNone.
Tests whether this JS value is a JS string.
If this JS value is a string value, this function copies the JS string value into Wasm linear memory, encoded as UTF-8, and returns it as a Rust String.
To avoid the copying and re-encoding, consider theJsString::try_from() function from js-sysinstead.
If this JS value is not an instance of a string or if it’s not valid utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings are encoded as UTF-8. This can cause the Rust string to look a bit different than the JS string sometimes. For more details see thedocumentation about the str type which contains a few caveats about the encodings.
Returns the bool value of this JS value if it’s an instance of a boolean.
If this JS value is not an instance of a boolean then this returnsNone.
Tests whether this JS value is null
Tests whether this JS value is undefined
Tests whether this JS value is null or undefined
Tests whether the type of this JS value is symbol
Tests whether typeof self == "object" && self !== null.
Tests whether this JS value is an instance of Array.
Tests whether the type of this JS value is function.
Tests whether the type of this JS value is bigint.
Tests whether the value is “truthy”.
Tests whether the value is “falsy”.
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.
Converts this type into a shared reference of the (usually inferred) input type.
Converts this type into a shared reference of the (usually inferred) input type.
Converts this type into a shared reference of the (usually inferred) input type.
The resulting type after dereferencing.
Dereferences the value.
The singular concrete type that all generic variants can be transmuted on
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
The Wasm ABI type that this converts from when coming back out from the ABI boundary.
Recover a Self from Self::Abi. Read more
The Wasm ABI type that this converts into when crossing the ABI boundary.
Convert self into Self::Abi so that it can be sent across the wasm ABI boundary.
The Wasm ABI type that this converts into when crossing the ABI boundary.
Convert self into Self::Abi so that it can be sent across the wasm ABI boundary.
Performs a dynamic instanceof check to see whether the JsValueprovided is an instance of this type. Read more
Performs a zero-cost unchecked conversion from a JsValue into an instance of Self Read more
Performs a zero-cost unchecked conversion from a &JsValue into an instance of &Self. Read more
Test whether this JS value has a type T. Read more
Performs a dynamic cast (checked at runtime) of this value into the target type T. Read more
Performs a dynamic cast (checked at runtime) of this value into the target type T. Read more
Performs a zero-cost unchecked cast into the specified type. Read more
Performs a zero-cost unchecked cast into a reference to the specified type. Read more
Test whether this JS value is an instance of the type T. Read more
Performs a dynamic check to see whether the JsValue provided is a value of this type. Read more
Same as RefFromWasmAbi::Abi
Same as RefFromWasmAbi::Anchor
Same as RefFromWasmAbi::ref_from_abi
Tests whether the argument is a “none” instance. If so it will be deserialized as None, and otherwise it will be passed toFromWasmAbi.
Returns an ABI instance indicating “none”, which JS will interpret as the None branch of this option. Read more
Returns an ABI instance indicating “none”, which JS will interpret as the None branch of this option. Read more
The type that this value resolves to.
The Wasm ABI type references to Self are recovered from.
The type that holds the reference to Self for the duration of the invocation of the function that has an &Self parameter. This is required to ensure that the lifetimes don’t persist beyond one function call, and so that they remain anonymous.
Recover a Self::Anchor from Self::Abi. Read more