Uint8ClampedArray in js_sys - Rust (original) (raw)

Struct Uint8ClampedArray

pub struct Uint8ClampedArray { /* private fields */ }

Source

Source

AnUint8ClampedArray()which creates an array with an internal buffer large enough for length elements.

MDN documentation

Source

Source

AnUint8ClampedArray()which creates an array with the given buffer but is a view starting at byte_offset.

MDN documentation

Source

AnUint8ClampedArray()which creates an array with the given buffer but is a view starting at byte_offset for length elements.

MDN documentation

Source

The fill() method fills all the elements of an array from a start index to an end index with a static value. The end index is not included.

MDN documentation

Source

The buffer accessor property represents the ArrayBuffer referenced by a TypedArray at construction time.

Source

The subarray() method returns a new TypedArray on the sameArrayBuffer store and with the same element types as for thisTypedArray object.

Source

The slice() method returns a shallow copy of a portion of a typed array into a new typed array object. This method has the same algorithm as Array.prototype.slice().

Source

The forEach() method executes a provided function once per array element. This method has the same algorithm asArray.prototype.forEach(). TypedArray is one of the typed array types here.

Source

The forEach() method executes a provided function once per array element. This method has the same algorithm asArray.prototype.forEach(). TypedArray is one of the typed array types here.

Source

The length accessor property represents the length (in elements) of a typed array.

Source

The byteLength accessor property represents the length (in bytes) of a typed array.

Source

The byteOffset accessor property represents the offset (in bytes) of a typed array from the start of its ArrayBuffer.

Source

The set() method stores multiple values in the typed array, reading input values from a specified array.

Source

Gets the value at idx, counting from the end if negative.

Source

The copyWithin() method shallow copies part of a typed array to another location in the same typed array and returns it, without modifying its size.

MDN documentation

Source

Gets the value at idx, equivalent to the javascript my_var = arr[idx].

Source

Sets the value at idx, equivalent to the javascript arr[idx] = value.

Source

Creates a JS typed array which is a view into wasm’s linear memory at the slice specified.

This function returns a new typed array which is a view into wasm’s memory. This view does not copy the underlying data.

Safety

Views into WebAssembly memory are only valid so long as the backing buffer isn’t resized in JS. Once this function is called any future calls to Box::new (or malloc of any form) may cause the returned value here to be invalidated. Use with caution!

Additionally the returned object can be safely mutated but the input slice isn’t guaranteed to be mutable.

Finally, the returned object is disconnected from the input slice’s lifetime, so there’s no guarantee that the data is read at the right time.

Creates a JS typed array which is a view into wasm’s linear memory at the specified pointer with specified length.

This function returns a new typed array which is a view into wasm’s memory. This view does not copy the underlying data.

Safety

Views into WebAssembly memory are only valid so long as the backing buffer isn’t resized in JS. Once this function is called any future calls to Box::new (or malloc of any form) may cause the returned value here to be invalidated. Use with caution!

Additionally the returned object can be safely mutated, the changes are guaranteed to be reflected in the input array.

Copy the contents of this JS typed array into the destination Rust pointer.

This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.

Safety

This function requires dst to point to a buffer large enough to fit this array’s contents.

Copy the contents of this JS typed array into the destination Rust slice.

This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.

Panics

This function will panic if this typed array’s length is different than the length of the provided dst array.

Copy the contents of this JS typed array into the destination Rust slice.

This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.

Panics

This function will panic if this typed array’s length is different than the length of the provided dst array.

Copy the contents of the source Rust slice into this JS typed array.

This function will efficiently copy the memory from within the Wasm module’s own linear memory to this typed array.

Panics

This function will panic if this typed array’s length is different than the length of the provided src array.

Efficiently copies the contents of this JS typed array into a new Vec.

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

👎Deprecated: Use Object::hasOwn instead.

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Returns the f64 value of this JS value if it’s an instance of a number.

If this JS value is not an instance of a number then this returnsNone.

Tests whether this JS value is a JS string.

If this JS value is a string value, this function copies the JS string value into Wasm linear memory, encoded as UTF-8, and returns it as a Rust String.

To avoid the copying and re-encoding, consider theJsString::try_from() function from js-sysinstead.

If this JS value is not an instance of a string or if it’s not valid utf-8 then this returns None.

UTF-16 vs UTF-8

JavaScript strings in general are encoded as UTF-16, but Rust strings are encoded as UTF-8. This can cause the Rust string to look a bit different than the JS string sometimes. For more details see thedocumentation about the str type which contains a few caveats about the encodings.

Returns the bool value of this JS value if it’s an instance of a boolean.

If this JS value is not an instance of a boolean then this returnsNone.

Tests whether this JS value is null

Tests whether this JS value is undefined

Tests whether this JS value is null or undefined

Tests whether the type of this JS value is symbol

Tests whether typeof self == "object" && self !== null.

Tests whether this JS value is an instance of Array.

Tests whether the type of this JS value is function.

Tests whether the type of this JS value is bigint.

Tests whether the value is “truthy”.

Tests whether the value is “falsy”.

Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.

MDN documentation

Source

Source

Converts this type into a shared reference of the (usually inferred) input type.

Source

Source

Converts this type into a shared reference of the (usually inferred) input type.

Source

Source

Converts this type into a shared reference of the (usually inferred) input type.

Source

Source

Source

Source

Source

The resulting type after dereferencing.

Source

Dereferences the value.

Source

Source

The singular concrete type that all generic variants can be transmuted on

Source

Source

Converts to this type from the input type.

Source

Source

Converts to this type from the input type.

Source

Source

Converts to this type from the input type.

Source

Source

Converts to this type from the input type.

Source

Source

The Wasm ABI type that this converts from when coming back out from the ABI boundary.

Source

Recover a Self from Self::Abi. Read more

Source

Source

The Wasm ABI type that this converts into when crossing the ABI boundary.

Source

Convert self into Self::Abi so that it can be sent across the wasm ABI boundary.

Source

Source

The Wasm ABI type that this converts into when crossing the ABI boundary.

Source

Convert self into Self::Abi so that it can be sent across the wasm ABI boundary.

Source

Source

Performs a dynamic instanceof check to see whether the JsValueprovided is an instance of this type. Read more

Source

Performs a zero-cost unchecked conversion from a JsValue into an instance of Self Read more

Source

Performs a zero-cost unchecked conversion from a &JsValue into an instance of &Self. Read more

Source

Test whether this JS value has a type T. Read more

Source

Performs a dynamic cast (checked at runtime) of this value into the target type T. Read more

Source

Performs a dynamic cast (checked at runtime) of this value into the target type T. Read more

Source

Performs a zero-cost unchecked cast into the specified type. Read more

Source

Performs a zero-cost unchecked cast into a reference to the specified type. Read more

Source

Test whether this JS value is an instance of the type T. Read more

Source

Performs a dynamic check to see whether the JsValue provided is a value of this type. Read more

Source

Source

Same as RefFromWasmAbi::Abi

Source

Same as RefFromWasmAbi::Anchor

Source

Same as RefFromWasmAbi::ref_from_abi

Source

Source

Tests whether the argument is a “none” instance. If so it will be deserialized as None, and otherwise it will be passed toFromWasmAbi.

Source

Source

Returns an ABI instance indicating “none”, which JS will interpret as the None branch of this option. Read more

Source

Source

Returns an ABI instance indicating “none”, which JS will interpret as the None branch of this option. Read more

Source

Source

The type that this value resolves to.

Source

Source

The Wasm ABI type references to Self are recovered from.

Source

The type that holds the reference to Self for the duration of the invocation of the function that has an &Self parameter. This is required to ensure that the lifetimes don’t persist beyond one function call, and so that they remain anonymous.

Source

Recover a Self::Anchor from Self::Abi. Read more

Source

Source

Source

Source

Source

Source

Source

Source