AsyncIterable in js_sys - Rust (original) (raw)
Trait AsyncIterable
pub trait AsyncIterable {
type Item;
}Expand description
Trait for types known to implement the iterator protocol on Symbol.asyncIterator
pub trait AsyncIterable {
type Item;
}Expand description
Trait for types known to implement the iterator protocol on Symbol.asyncIterator